@@ -11,6 +11,14 @@ import { RadioInput } from '../radio';
 import { Checkbox } from '../checkbox';
 import { PersistentVolumeClaimModel } from '../../models';
 import { StorageClass } from '../storage-class-form';
+import {
+  cephRBDProvisionerSuffix,
+  provisionerAccessModeMapping,
+  initialAccessModes,
+  accessModeRadios,
+  dropdownUnits,
+  getAccessModeForProvisioner,
+} from './shared';
 
 const NameValueEditorComponent = (props) => (
   <AsyncComponent
@@ -19,34 +27,11 @@ const NameValueEditorComponent = (props) => (
   />
 );
 
-const cephRBDProvisionerSuffix = 'rbd.csi.ceph.com';
-
-//See https://kubernetes.io/docs/concepts/storage/persistent-volumes/#types-of-persistent-volumes for more details
-const provisionerAccessModeMapping = {
-  'kubernetes.io/no-provisioner': ['ReadWriteOnce'],
-  'kubernetes.io/aws-ebs': ['ReadWriteOnce'],
-  'kubernetes.io/gce-pd': ['ReadWriteOnce', 'ReadOnlyMany'],
-  'kubernetes.io/glusterfs': ['ReadWriteOnce', 'ReadWriteMany', 'ReadOnlyMany'],
-  'kubernetes.io/cinder': ['ReadWriteOnce'],
-  'kubernetes.io/azure-file': ['ReadWriteOnce', 'ReadWriteMany', 'ReadOnlyMany'],
-  'kubernetes.io/azure-disk': ['ReadWriteOnce'],
-  'kubernetes.io/quobyte': ['ReadWriteOnce', 'ReadWriteMany', 'ReadOnlyMany'],
-  'kubernetes.io/rbd': ['ReadWriteOnce', 'ReadOnlyMany'],
-  'kubernetes.io/vsphere-volume': ['ReadWriteOnce', 'ReadWriteMany'],
-  'kubernetes.io/portworx-volume': ['ReadWriteOnce', 'ReadWriteMany'],
-  'kubernetes.io/scaleio': ['ReadWriteOnce', 'ReadOnlyMany'],
-  'kubernetes.io/storageos': ['ReadWriteOnce'],
-};
-
 // This form is done a little odd since it is used in both its own page and as
 // a sub form inside the attach storage page.
 export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
   const [accessModeHelp, setAccessModeHelp] = React.useState('Permissions to the mounted drive.');
-  const [allowedAccessModes, setAllowedAccessModes] = React.useState([
-    'ReadWriteOnce',
-    'ReadWriteMany',
-    'ReadOnlyMany',
-  ]);
+  const [allowedAccessModes, setAllowedAccessModes] = React.useState(initialAccessModes);
   const [storageClass, setStorageClass] = React.useState('');
   const [pvcName, setPvcName] = React.useState('');
   const [accessMode, setAccessMode] = React.useState('ReadWriteOnce');
@@ -55,25 +40,6 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
   const [useSelector, setUseSelector] = React.useState(false);
   const [nameValuePairs, setNameValuePairs] = React.useState([['', '']]);
   const [storageProvisioner, setStorageProvisioner] = React.useState('');
-  const accessModeRadios = [
-    {
-      value: 'ReadWriteOnce',
-      title: 'Single User (RWO)',
-    },
-    {
-      value: 'ReadWriteMany',
-      title: 'Shared Access (RWX)',
-    },
-    {
-      value: 'ReadOnlyMany',
-      title: 'Read Only (ROX)',
-    },
-  ];
-  const dropdownUnits = {
-    Mi: 'MiB',
-    Gi: 'GiB',
-    Ti: 'TiB',
-  };
   const { namespace, onChange } = props;
 
   React.useEffect(() => {
@@ -148,12 +114,6 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
     setNameValuePairs(updatedNameValuePairs);
   };
 
-  const getAccessModeForProvisioner = (provisioner: string) => {
-    return provisioner && isCephProvisioner(provisioner)
-      ? ['ReadWriteOnce', 'ReadWriteMany']
-      : ['ReadWriteOnce', 'ReadWriteMany', 'ReadOnlyMany'];
-  };
-
   const handleStorageClass = (updatedStorageClass) => {
     const provisioner: string = updatedStorageClass?.provisioner || '';
     //if the provisioner is unknown or no storage class selected, user should be able to set any access mode
@@ -163,8 +123,8 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
     //setting message to display for various modes when a storage class of a know provisioner is selected
     const displayMessage =
       provisionerAccessModeMapping[provisioner] || isCephProvisioner(provisioner)
-        ? 'Access mode is set by storage class and cannot be changed.'
-        : 'Permissions to the mounted drive.';
+        ? 'Access mode is set by storage class and cannot be changed'
+        : 'Permissions to the mounted drive';
     setAccessMode('ReadWriteOnce');
     setAccessModeHelp(displayMessage);
     //setting accessMode to default with the change to Storage Class selection
@@ -219,7 +179,7 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
           required
         />
         <p className="help-block" id="pvc-name-help">
-          A unique name for the storage claim within the project.
+          A unique name for the storage claim within the project
         </p>
       </div>
       <label className="control-label co-required" htmlFor="access-mode">
@@ -266,7 +226,7 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
         inputID="request-size-input"
       />
       <p className="help-block" id="request-size-help">
-        Desired storage capacity.
+        Desired storage capacity
       </p>
       <Checkbox
         label="Use label selectors to request storage"
@@ -287,7 +247,7 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
           />
         )}
         <p className="help-block" id="label-selector-help">
-          Use label selectors to define how storage is created.
+          Use label selectors to define how storage is created
         </p>
       </div>
     </div>
@@ -324,7 +284,12 @@ export const CreatePVCPage: React.FC<CreatePVCPageProps> = (props) => {
       <h1 className="co-m-pane__heading co-m-pane__heading--baseline">
         <div className="co-m-pane__name">{title}</div>
         <div className="co-m-pane__heading-link">
-          <Link to={`/k8s/ns/${namespace}/persistentvolumeclaims/~new`} id="yaml-link" replace>
+          <Link
+            to={`/k8s/ns/${namespace}/persistentvolumeclaims/~new`}
+            id="yaml-link"
+            data-test="yaml-link"
+            replace
+          >
             Edit YAML
           </Link>
         </div>
